@@ -349,12 +349,12 @@ void ConfigList::connectAccounts( )
     account->disconnect();
 
     //connect
-    connect( account, SIGNAL( sigConfigChanged() ), this, SLOT( slotAccountConfigChanged() ) );
-    connect( account, SIGNAL( sigDeleteReady( TQString ) ), this, SLOT( slotCheckDeletionState( TQString ) ) );
-    connect( account, SIGNAL( sigShowBodiesReady( TQString ) ), this, SLOT( slotCheckShowBodiesState( TQString ) ) );
-    connect( account, SIGNAL( sigMessageWindowOpened() ), this, SLOT( slotMessageWindowOpened() ) );
-    connect( account, SIGNAL( sigMessageWindowClosed() ), this, SLOT( slotMessageWindowClosed() ) );
-    connect( account, SIGNAL( sigRefreshReady( TQString ) ), this, SLOT( slotCheckRefreshState( TQString ) ) );
+    connect( account, TQ_SIGNAL( sigConfigChanged() ), this, TQ_SLOT( slotAccountConfigChanged() ) );
+    connect( account, TQ_SIGNAL( sigDeleteReady( TQString ) ), this, TQ_SLOT( slotCheckDeletionState( TQString ) ) );
+    connect( account, TQ_SIGNAL( sigShowBodiesReady( TQString ) ), this, TQ_SLOT( slotCheckShowBodiesState( TQString ) ) );
+    connect( account, TQ_SIGNAL( sigMessageWindowOpened() ), this, TQ_SLOT( slotMessageWindowOpened() ) );
+    connect( account, TQ_SIGNAL( sigMessageWindowClosed() ), this, TQ_SLOT( slotMessageWindowClosed() ) );
+    connect( account, TQ_SIGNAL( sigRefreshReady( TQString ) ), this, TQ_SLOT( slotCheckRefreshState( TQString ) ) );
 
     //get next account
     ++it;
