@@ -12,7 +12,7 @@
 #ifndef SHOWMAILDIALOG_H
 #define SHOWMAILDIALOG_H
 
-//QT headers
+//TQt headers
 #include <tqlayout.h>
 #include <tqlabel.h>
 
@@ -36,7 +36,7 @@
 class ShowMailDialog : public KDialogBase
 {
 
-Q_OBJECT
+TQ_OBJECT
 
 public:
 
